
sncosmo.PhotoTyper
==================

.. currentmodule:: sncosmo

.. autoclass:: PhotoTyper
   :show-inheritance:

   
   
   


   
   
   .. rubric:: Methods Summary

   .. autosummary::
   
      ~PhotoTyper.add_model
      ~PhotoTyper.classify
   
   


   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: add_model
   .. automethod:: classify

   
   